==> wallaroo-2022.4.0rc3-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/models/models_upload_response_200_insert_models_returning_item.py <==
from typing import Any, Dict, List, Type, TypeVar

import attr

from ..models.models_upload_response_200_insert_models_returning_item_models_item import \
    ModelsUploadResponse200InsertModelsReturningItemModelsItem

T = TypeVar("T", bound="ModelsUploadResponse200InsertModelsReturningItem")

@attr.s(auto_attribs=True)
class ModelsUploadResponse200InsertModelsReturningItem:
    """ Upload model response detail.

    Attributes:
        models (List[ModelsUploadResponse200InsertModelsReturningItemModelsItem]):  List of uploaded models.
    """

    models: List[ModelsUploadResponse200InsertModelsReturningItemModelsItem]
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        models = []
        for models_item_data in self.models:
            models_item = models_item_data.to_dict()

            models.append(models_item)





        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "models": models,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        d = src_dict.copy()
        models = []
        _models = d.pop("models")
        for models_item_data in (_models):
            models_item = ModelsUploadResponse200InsertModelsReturningItemModelsItem.from_dict(models_item_data)



            models.append(models_item)


        models_upload_response_200_insert_models_returning_item = cls(
            models=models,
        )

        models_upload_response_200_insert_models_returning_item.additional_properties = d
        return models_upload_response_200_insert_models_returning_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties

==> wallaroo-2023.2.0rc1-py3-none-any.whl: wallaroo/wallaroo_ml_ops_api_client/models/models_upload_response_200_insert_models_returning_item.py <==
from typing import TYPE_CHECKING, Any, Dict, List, Type, TypeVar

import attr

if TYPE_CHECKING:
  from ..models.models_upload_response_200_insert_models_returning_item_models_item import \
      ModelsUploadResponse200InsertModelsReturningItemModelsItem





T = TypeVar("T", bound="ModelsUploadResponse200InsertModelsReturningItem")


@attr.s(auto_attribs=True)
class ModelsUploadResponse200InsertModelsReturningItem:
    """  Upload model response detail.

        Attributes:
            models (List['ModelsUploadResponse200InsertModelsReturningItemModelsItem']):  List of uploaded models.
     """

    models: List['ModelsUploadResponse200InsertModelsReturningItemModelsItem']
    additional_properties: Dict[str, Any] = attr.ib(init=False, factory=dict)


    def to_dict(self) -> Dict[str, Any]:
        models = []
        for models_item_data in self.models:
            models_item = models_item_data.to_dict()

            models.append(models_item)





        field_dict: Dict[str, Any] = {}
        field_dict.update(self.additional_properties)
        field_dict.update({
            "models": models,
        })

        return field_dict



    @classmethod
    def from_dict(cls: Type[T], src_dict: Dict[str, Any]) -> T:
        from ..models.models_upload_response_200_insert_models_returning_item_models_item import \
            ModelsUploadResponse200InsertModelsReturningItemModelsItem
        d = src_dict.copy()
        models = []
        _models = d.pop("models")
        for models_item_data in (_models):
            models_item = ModelsUploadResponse200InsertModelsReturningItemModelsItem.from_dict(models_item_data)



            models.append(models_item)


        models_upload_response_200_insert_models_returning_item = cls(
            models=models,
        )

        models_upload_response_200_insert_models_returning_item.additional_properties = d
        return models_upload_response_200_insert_models_returning_item

    @property
    def additional_keys(self) -> List[str]:
        return list(self.additional_properties.keys())

    def __getitem__(self, key: str) -> Any:
        return self.additional_properties[key]

    def __setitem__(self, key: str, value: Any) -> None:
        self.additional_properties[key] = value

    def __delitem__(self, key: str) -> None:
        del self.additional_properties[key]

    def __contains__(self, key: str) -> bool:
        return key in self.additional_properties
